@@ -95,11 +95,16 @@ autosummary_generate = True
 
 # -- Options for HTML output -------------------------------------------------
 
+import sphinx_book_theme
+
 # The theme to use for HTML and HTML Help pages.  See the documentation for
 # a list of builtin themes.
 #
-html_theme = 'nature'
+html_theme = 'sphinx_book_theme'
 
+html_theme_options = {
+    'logo_only': True,
+}
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
 # so a file named "default.css" will overwrite the builtin "default.css".
@@ -112,7 +117,7 @@ html_favicon = '_static/images/favicon.ico'
 
 # The name of an image file (relative to this directory) to place at the top
 # of the sidebar.
-html_logo = '_static/images/logo.jpg'
+html_logo = '_static/images/logo.png'
 
 # Output file base name for HTML help builder.
 htmlhelp_basename = 'qiskit_iqm-doc'
