@@ -18,8 +18,7 @@ import uuid
 
 import mockito
 import pytest
-from iqm_client.iqm_client import (CircuitExecutionError, IQMClient, RunResult,
-                                   RunStatus)
+from iqm_client.iqm_client import IQMClient, RunResult, RunStatus
 from mockito import mock, when
 from qiskit.providers import JobStatus
 from qiskit.result import Counts
@@ -63,37 +62,32 @@ def test_cancel_raises(job):
 
 
 def test_status_for_ready_result(job):
-    job._result = ['11', '10', '10']
+    job._result = [['11', '10', '10']]
     assert job.status() == JobStatus.DONE
     result = job.result()
     assert isinstance(result, QiskitResult)
     assert result.get_memory() == ['11', '10', '10']
 
 
-def test_status_done(job, iqm_result_single_register):
-    client_result = RunResult(status=RunStatus.READY, measurements=iqm_result_single_register)
-    when(job._client).get_run(uuid.UUID(job.job_id())).thenReturn(client_result)
+def test_status_done(job):
+    client_result = RunResult(status=RunStatus.READY, measurements=None)
+    when(job._client).get_run_status(uuid.UUID(job.job_id())).thenReturn(client_result)
     assert job.status() == JobStatus.DONE
-    assert job._result is not None
-
-    # Assert that repeated call does not query the client (i.e. works without calling the mocked get_run)
-    assert job.status() == JobStatus.DONE
-    mockito.verify(job._client, times=1).get_run(uuid.UUID(job.job_id()))
+    assert job._result is None
 
 
 def test_status_running(job):
-    when(job._client).get_run(uuid.UUID(job.job_id())).thenReturn(RunResult(status=RunStatus.PENDING))
+    when(job._client).get_run_status(uuid.UUID(job.job_id())).thenReturn(RunResult(status=RunStatus.PENDING))
     assert job.status() == JobStatus.RUNNING
 
 
 def test_status_fail(job):
-    when(job._client).get_run(uuid.UUID(job.job_id())).thenRaise(CircuitExecutionError)
-    with pytest.raises(CircuitExecutionError):
-        job.status()
+    when(job._client).get_run_status(uuid.UUID(job.job_id())).thenReturn(RunResult(status=RunStatus.FAILED))
+    assert job.status() == JobStatus.ERROR
 
 
 def test_result(job, iqm_result_two_registers):
-    client_result = RunResult(status=RunStatus.READY, measurements=iqm_result_two_registers)
+    client_result = RunResult(status=RunStatus.READY, measurements=[iqm_result_two_registers])
     when(job._client).wait_for_results(uuid.UUID(job.job_id())).thenReturn(client_result)
 
     result = job.result()
@@ -108,3 +102,14 @@ def test_result(job, iqm_result_two_registers):
     assert isinstance(result, QiskitResult)
     assert job.status() == JobStatus.DONE
     mockito.verify(job._client, times=1).wait_for_results(uuid.UUID(job.job_id()))
+
+def test_result_multiple_circuits(job, iqm_result_two_registers):
+    client_result = RunResult(status=RunStatus.READY, measurements=[iqm_result_two_registers, iqm_result_two_registers])
+    when(job._client).wait_for_results(uuid.UUID(job.job_id())).thenReturn(client_result)
+
+    result = job.result()
+
+    assert isinstance(result, QiskitResult)
+    for circuit_idx in range(2):
+        assert result.get_memory(circuit_idx) == ['0100 11', '0100 10', '0100 01', '0100 10']
+        assert result.get_counts(circuit_idx) == Counts({'0100 11': 1, '0100 10': 2, '0100 01': 1})
